abacusai.video_gen_settings — AbacusAI documentation

# abacusai.video_gen_settings

## Classes

`VideoGenSettings` | Video generation settings

## Module Contents

class abacusai.video_gen_settings.VideoGenSettings(client, prompt=None, negativePrompt=None, cfgScale=None, mode=None, aspectRatio=None, duration=None, loop=None, startFrame=None, endFrame=None, rewritePrompt=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Video generation settings

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - prompt (dict) – The prompt for the video.

    - negativePrompt (dict) – The negative prompt for the video.

    - cfgScale (dict) – The flexibility scale for video generation.

    - mode (dict) – The video generation mode (standard or professional).

    - aspectRatio (dict) – The aspect ratio of the video in seconds.

    - duration (dict) – The duration of the video.

    - loop (dict) – Whether the video should loop.

    - startFrame (dict) – The start frame of the video.

    - endFrame (dict) – The end frame of the video.

    - rewritePrompt (dict) – Whether to rewrite the prompt.

  prompt
  negative_prompt
  cfg_scale
  mode
  aspect_ratio
  duration
  loop
  start_frame
  end_frame
  rewrite_prompt
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict